# Модуль математических функций (renat)

Модуль renat предоставляет набор математических функций, таких как возведение в квадрат, куб, извлечение квадратного и кубического корня, возведение в степень, арифметическое и геометрическое среднее.

## Установка

Для установки модуля renat выполните команду: pip install renat


## Использование

Пример использования модуля:

```python
import renat

print(renat.kv(2))         # Вывод: 4
print(renat.kub(2))        # Вывод: 8
print(renat.kv_kor(4))     # Вывод: 2.0
print(renat.kub_kor(8))    # Вывод: 2.0
print(renat.step(2, 3))    # Вывод: 8
print(renat.arif(1, 2, 3)) # Вывод: 2.0
print(renat.geo(1, 2, 4))  # Вывод: 1.6817928305074292